#!/usr/bin/python
#usage python ppastats.py PPATEAM (ex: webupd8team) PPA (ex: gthumb) DIST (Ubuntu version eg maverick) ARCH (ubuntu arch eg i386 or amd64)

#example - highest downloaded file: python ppastats.py webupd8team y-ppa-manager maverick amd64 | tr '\t' ',' | cut -d ',' -f3 | sort -gr

import sys
from launchpadlib.launchpad import Launchpad

PPAOWNER = sys.argv[1]
PPA = sys.argv[2]
desired_dist_and_arch = 'https://api.launchpad.net/devel/ubuntu/' + sys.argv[3] + '/' + sys.argv[4]



cachedir = "~/.launchpadlib/cache/"
lp_ = Launchpad.login_anonymously('ppastats', 'edge', cachedir, version='devel')
owner = lp_.people[PPAOWNER]
archive = owner.getPPAByName(name=PPA)

for individualarchive in archive.getPublishedBinaries(status='Published',distro_arch_series=desired_dist_and_arch):

       x = individualarchive.getDownloadCount()
       if x > 0:
              print individualarchive.binary_package_name + "\t" + individualarchive.binary_package_version + "\t" + str(individualarchive.getDownloadCount())
       elif x < 1:
              print '0'



#!/usr/bin/python
import commands, re

cpp=commands.getoutput("find . -name '*.cpp' | xargs wc -l |grep celkem")
headers=commands.getoutput("find . -name '*.h' | xargs wc -l |grep celkem")
html=commands.getoutput("find . -name '*.html' | xargs wc -l |grep celkem")

intcpp=int(re.findall(r"\d+",cpp)[0])
intheaders=int(re.findall(r"\d+",headers)[0])
inthtml=int(re.findall(r"\d+",html)[0])

print "##########################"
print "##       QupZilla       ##"
print "##########################"
print "\n"
print "Lines in Headers (.h files): "+str(intheaders)
print "Lines in Sources (.cpp files): "+str(intcpp)
print "Lines in Pages (.html files): "+str(inthtml)
print "----------------------------------------"
print "\n"
print ":::  "+str(intheaders + intcpp + inthtml)+" LINES IN SUMMARY  :::"
print "\n"
